@@ -9,7 +9,7 @@ export async function init(pluginAPI,config) {
 
     await pluginAPI.loadScripts(['queries/esQueryUtils.js']);
     
-    ecoreSync=new EcoreSync(pluginAPI.require('eventBroker'),plugin.require('ecore').Ecore);
+    ecoreSync=new EcoreSync(pluginAPI.require('eventBroker'),pluginAPI.require('ecore').Ecore);
 
     let instances=[];
     for(let i=0;i<config.instances.length;i++) {
