@@ -126,9 +126,13 @@ class GraphView{
         } )
 
         // XGEE key listener
-        editorDOM.addEventListener('keydown', async (event) => { 
+        editorDOM.addEventListener('keydown', (event) => { 
+
+            //sure do not want any further propagation
+            event.stopImmediatePropagation();
+            event.stopPropagation();  
+            event.preventDefault();
 
-                  
             var target={};
             target.editorId=self.graphController.model.editorId;
             target.DOM=null
@@ -169,7 +173,7 @@ class GraphView{
                 target.eObject=self.graphController.eObject
             }                                 
 
-            event.stopPropagation();      
+               
             self.eventBroker.publish('XGEE/KEYPRESS',{target:target,eObject:null,DOM:null,key:event.key, shiftKey:event.shiftKey, ctrlKey: event.ctrlKey, altKey: event.altKey})
         } )
 
